import { scaleOrdinal } from 'd3'

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#c11d1c', '#eae600'])

const sizeScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([80, 50])

export const fruitBowl = (selection, props) => {
  const { fruits, height } = props
  
  const bowl = selection.selectAll('rect')
  	.data([null])
  	.enter().append('rect')
      .attr('y', 100)
  		.attr('width', 930)
  		.attr('height', 300)
  		.attr('rx', 300 / 2)
  		.attr('fill', '#77aaff')
  		.attr('opacity', 0.4)
  		
  
  const groups = selection.selectAll('g')
  	.data(fruits, d => d.id)
  const groupsEnter = groups.enter().append('g')
  groupsEnter
    .merge(groups)
  		.attr('transform', (d, i) => 
				`translate(${i * 180 + 100},${height / 2})`
      )
  groups.exit().remove()
  
  
  groupsEnter
    .append('circle')
  		.attr('r', 0)
  	.merge(groups.select('circle'))
  		.transition().duration(1000)
  		.attr('r', d => sizeScale(d.type))
  		.attr('fill', d => colorScale(d.type))

  groupsEnter
    .append('text')
  	.merge(groups.select('text'))
  		.text(d => d.type)
  		.attr('y', 200)
}
